pub struct NonInlinedRequestStats {
pub allow_sync_calls: Option<u64>,
pub parallel_dispatch: Option<u64>,
pub task: Option<u64>,
pub unknown_thread: Option<u64>,
pub reentrant: Option<u64>,
pub channel_wait_not_yet_registered: Option<u64>,
pub no_thread_migration: Option<u64>,
/* private fields */
}Expand description
Breakdown of reasons why requests were not inlined by the driver runtime.
Fields
allow_sync_calls: Option<u64>Calling from a non-blocking to a blocking (ALLOW_SYNC_CALLS) dispatcher.
parallel_dispatch: Option<u64>Another thread was already dispatching a request.
task: Option<u64>The request was a task.
unknown_thread: Option<u64>The request was queued from an unknown thread.
reentrant: Option<u64>The request would have been reentrant.
channel_wait_not_yet_registered: Option<u64>Channel wait was not yet registered when the message was received.
no_thread_migration: Option<u64>Called into a dispatcher that wasn’t allowed to migrate threads.