pub struct QueuedTaskInfo {
pub ptr: Option<u64>,
pub handler: Option<u64>,
pub initiating_dispatcher: Option<u64>,
pub initiating_dispatcher_name: Option<String>,
pub initiating_driver: Option<u64>,
pub initiating_driver_url: Option<String>,
/* private fields */
}Expand description
Diagnostic information for a task queued on a dispatcher.
Fields
ptr: Option<u64>Address of the queued async_task_t.
handler: Option<u64>Address of the task handler function.
initiating_dispatcher: Option<u64>Address of the dispatcher that queued this task, if queued from a runtime thread.
initiating_dispatcher_name: Option<String>Name of the dispatcher that queued this task, if known.
initiating_driver: Option<u64>Address of the driver that queued this task, if queued from a runtime thread.
initiating_driver_url: Option<String>URL of the driver that queued this task, if known.